@@ -3,7 +3,7 @@ package Toolforge::MixNMatch::Print;
 use strict;
 use warnings;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 1;
 
@@ -28,15 +28,15 @@ This distributions is set of print routins for objects from Toolforge Mix'n'matc
 
 =item L<Toolforge::MixNMatch::Print::Catalog>
 
-TODO
+Mix'n'match user structure print.
 
 =item L<Toolforge::MixNMatch::Print::User>
 
-TODO
+Mix'n'match user structure print.
 
 =item L<Toolforge::MixNMatch::Print::YearMonth>
 
-TODO
+Mix'n'match year/month structure print.
 
 =back
 
@@ -58,6 +58,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
